Learn R Programming

EcoHydRology (version 0.3.8)

EcoHydRology-package: A community modeling foundation for Eco-Hydrology.

Description

This package provides a flexible foundation for scientists, engineers, and policy makers to base teaching exercises as well as for more applied use to model complex eco-hydrological interactions.

Arguments

Details

ll{ Package: EcoHydRology Type: Package Version: 0.3.8 Date: 2011-06-19 License: GPL-2 LazyLoad: yes } Included Energy Budget Functions: AtmosphericEmissivity EnvirEnergy EstCloudiness EvapHeat GroundHeat Longwave NetRad PotentialSolar RainHeat SatVaporDensity SensibleHeat Solar declination slopefactor solarangle solaraspect transmissivity Included Data Handeling Functions: get_gsod_stn build_gsod_forcing_data Included data: GSOD_history