Learn R Programming

EcoHydRology (version 0.3.7)

EnvirEnergy: The Surface Net Energy Budget

Description

Net Energy=S+La-Lt+S+E+R+G, where S is the net incident solar radiation, La is the atmospheric long wave radiation, Lt is the terrestrial long wave radiation, H is the sensible heat exchange, E is the energy flux associated with the latent heats of vaporization and condensation, G is ground heat conduction, P is heat added by precipitation

Usage

EnvirEnergy(lat, Jday, Tx, Tn, wind, relativehumidity, cloudiness, albedo, forest, slope, aspect, surftemp, surfemissivity,rain)

Arguments

lat
latitdue [rad]
Jday
Julian day / day of the year, 1-365 [day]
Tx
Maximum daily temperature [C]
Tn
Minimum daily temperature [C]
wind
Average daily windspeed [m/s]
relativehumidity
Relative humidity; if negative, air vapor density will be approximated [-]
cloudiness
Fraction of the sky covered in clouds,if negative, cloudiness will be approximated [-]
albedo
#albedo: surface albedo or reflectivity [-]
forest
Forest or vegeation cover [-]
slope
Slope of the ground [rad]
aspect
Ground aspect [rad from north]
surftemp
surface temperature [C]
surfemissivity
surfice emissivity: [-]
rain
precipitation [mm/day]

Value

  • NetEnergySurface net energy
  • .

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function(lat,Jday,Tx,Tn,wind,relativehumidity,cloudiness,albedo,forest,slope,aspect,surftemp,surfemissivity){
if(cloudiness<0){cloudiness<-EstCloudiness(lat,Jday,Tx,Tn)}

airtemp<-(Tx+Tn)/2 #average daily air temperature [C]

return(Solar(lat,Jday,Tx,Tn,albedo,forest,slope,aspect)+Longwave(AtmosphericEmissivity(airtemp,cloudiness),airtemp)-Longwave(surfemissivity,surftemp)+SensibleHeat(surftemp,airtemp,wind)+EvapHeat(surftemp,airtemp,relativehumidity,Tn,wind)+RainHeat(airtemp,rain)+GroundHeat())
  }

Run the code above in your browser using DataLab