Learn R Programming

EcoHydRology (version 0.4.3)

EstCloudiness: Estimated Cloudiness

Description

Estimates the cloudiness of the atmosphere by scaling to atmospheric transmissivity

Usage

EstCloudiness(Tx=(-999), Tn=(-999), trans=NULL, transMin = 0.15, transMax = 0.75, opt = "linear")

Arguments

Tx
maximum daily temperature [C]
Tn
minimum daily temperature [C]
trans
transmissivity of the atmosphere (value between 0-1)
transMin
Transmissivities equal and below this value will return a cloudiness value of 1 (for linear approximation)
transMax
Transmissivities equal and above this value will return a cloudiness value of 0 (for linear approximation)
opt
Currently there are two options: "linear" (Campbell 1985) and "Black" (1956)

References

Campbell G.S. (1985) Soil Physics with Basic: Transport Models for Soil Plant Systems. Elsevier, New York

Black, J.N. (1956) The Distribution of Solar Radiation over the Earth's Surface. Theoretical and Applied Climatology 7:2 165-189

Examples

Run this code
EstCloudiness(trans=0.2)
EstCloudiness(20,12,opt="Black")

Run the code above in your browser using DataLab