Learn R Programming

EcoHydRology (version 0.4.9)

EvapHeat: Evaporative heat exchange between a wet surface and the surrounding air

Description

Evaporative heat exchange between a surface and the surrounding air [kJ m-2 d-1]. This function is only intended for wet surfaces, i.e., it assumes the vapor density at the surface is the saturation vapor density

Usage

EvapHeat(surftemp, airtemp, relativehumidity=NULL, Tn=NULL, wind=2)

Arguments

surftemp
surface temperature [C]
airtemp
average daily air temperature [C]
relativehumidity
relative humidity, 0-1 [-]
Tn
minimum dailiy air temperature, assumed to be dew point temperature if relativehumidity unknown [C]
wind
average daily windspeed [m/s]

References

Campbell, Gaylon S. An Introduction to Environmental Biophysics. New York: Springer-Verlag, 1977.

Examples

Run this code
EvapHeat(surftemp=15, airtemp=5, relativehumidity=0.7)

Run the code above in your browser using DataLab