Learn R Programming

EcoHydRology (version 0.3.7)

GSOD_history: ish-history.txt

Description

A station list to be used with the GSOD data files, showing the names and locations for each station. Note: Global summary of day contains a subset of the stations listed in this station history.

Usage

data(GSOD_history)

Arguments

source

ftp://ftp.ncdc.noaa.gov/pub/data/gsod/ish-history.csv

Examples

Run this code
data(GSOD_history)

Run the code above in your browser using DataLab