Learn R Programming

EcoHydRology (version 0.3.8)

GroundHeat: Heat conducted to the bottom of a snowpack

Description

The heat conducted to the bottom of a snowpack, assumed constant [kJ m-2 d-1]

Usage

GroundHeat()

Arguments

Value

    Examples

    Run this code
    ##---- Should be DIRECTLY executable !! ----
    ##-- ==>  Define data, use random,
    ##--	or do  help(data=index)  for the standard data sets.
    
    ## The function is currently defined as
    function(){
    # the heat conducted to the bottom of a snowpack, assumed constant [kJ m-2 d-1]
    
    return(173)
      }

    Run the code above in your browser using DataLab