Learn R Programming

EcoHydRology (version 0.4.11)

RunoffBreakdown: Daily overland runoff breakdown

Description

Determines the percentage of runoff that occurs on each day following a storm event, based on time to peak of a watershed.

Usage

RunoffBreakdown(Tp_hr, a = 4.5, HrPrcDelay = 4, numDaysReturn = 5)

Arguments

Tp_hr
Time to peak (hr).
a
The ratio of the time to recession to the time to peak. Default is 4.5
HrPrcDelay
Lag time (hr)
numDaysReturn
Number of days to return

Value

  • returns a vector corresponding to the amount of runoff per day

Examples

Run this code
RunoffBreakdown(5)

Run the code above in your browser using DataLab