Learn R Programming

EcoHydRology (version 0.4.7)

SnowMelt: Snow Melt Calculator

Description

Calculates snow pack accumulation and melt

Usage

SnowMelt(Date, precip_mm, Tmax_C, Tmin_C, lat_deg, slope = 0, aspect = 0, tempHt = 1, windHt = 2, groundAlbedo = 0.25, SurfEmissiv = 0.95, windSp = 2, forest = 0, startingSnowDepth_m = 0)

Arguments

Date
Vector of dates (class Date or character) in this format: "/
precip_mm
Precipitation in mm
Tmax_C
Daily maximum temperature (degrees C)
Tmin_C
Daily minimum temperature (degrees C)
lat_deg
Degrees latitude
slope
Overall slope of area of interest
aspect
Aspect of the area of interest
tempHt
height of temperature measurements (m)
windHt
height of wind measurements (m)
groundAlbedo
Ground Albedo (-)
SurfEmissiv
Surface Emissivity (-)
windSp
Wind speed - either a vector of measured values or a single value of average wind speed for the site (m/s)
forest
Forest cover - use this only when determining snowmelt under a canopy (-)
startingSnowDepth_m
The depth of the snow pack initially (m)

Value

  • This will return an 8 column data frame with nrow = length of input streamflow data. Column names are : Date, MaxT_C, MinT_C, Rain_mm, SnowfallWatEq_mm, SnowMelt_mm, NewSnow_m, SnowDepth_m

References

Walter, M.T. , E.S. Brooks, D.K. McCool, L.G. King, M. Molnau, J. Boll. 2005. Process-based snowmelt modeling: Does it require more input data than temperature-index modeling? Journal of Hydrology 300(1-4): 65-75

Examples

Run this code
##  
data(OwascoInlet)
sm <- SnowMelt(Date=OwascoInlet$date, precip_mm=OwascoInlet$P_mm, Tmax_C=OwascoInlet$Tmax_C, Tmin_C=OwascoInlet$Tmin_C, lat_deg=42)
summary(sm)

Run the code above in your browser using DataLab