Learn R Programming

EcoHydRology (version 0.4.6)

calib_swat_ex: A function demostrate an example series of steps to calibrate a reach in the SWAT2005 watershed model.

Description

A function demostrate an example series of steps to calibrate a reach in the SWAT2005 watershed model. This should act only as a simple demonstration, and should be modified to inidivduals use.

Usage

calib_swat_ex(flowgage, rch = 3)

Arguments

flowgage
A list in the format that would be returned from the get_usgs_gage
rch
The reach in the output.rch file you wish to calibrate against.

Value

  • List (of length 2) containing the results of the internally called DEoptim function. See DEoptim for more information.

Details

This should act only as a simple demonstration, and should be modified to inidivduals use.