Learn R Programming

EcoHydRology (version 0.4.7)

solaraspect: Solar Aspect

Description

Aspect angle of sun from north at solar noon [rad]

Usage

solaraspect(lat, Jday)

Arguments

lat
latitdue [rad]
Jday
Julian date or day of the year [day]

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function(lat,Jday){
# aspect angle of sun from north at solar noon [rad]

#lat: latitdue [rad]
#Jday: Julian date or day of the year [day]

return(acos((sin(0)*sin(lat) - sin(declination(Jday)))/(cos(0)*cos(lat))))
  }

Run the code above in your browser using DataLab