Learn R Programming

EcoHydRology (version 0.3.7)

EstCloudiness: Estimated Cloudiness

Description

Estimates the cloudiness of the atmosphere by scaling to atmospheric transmissivity

Usage

EstCloudiness(lat, Jday, Tx, Tn)

Arguments

lat
latitdue [rad]
Jday
Julian date or day of the year [day]
Tx
maximum daily temperature [C]
Tn
minimum daily temperature [C]

Value

    Examples

    Run this code
    ##---- Should be DIRECTLY executable !! ----
    ##-- ==>  Define data, use random,
    ##--	or do  help(data=index)  for the standard data sets.
    
    ## The function is currently defined as
    function(lat,Jday,Tx,Tn){
    # estimates the cloudiness of the atmosphere by scaling to atmospheric transmissivity
    
    #lat: latitdue [rad]
    #Jday: Julian date or day of the year [day]
    #Tx: maximum daily temperature [C]
    #Tn: minimum daily temperature [C]
    
    trans<-transmissivity(lat,Jday,Tx,Tn)
    
    if(1-(trans-0.15)/(0.75-0.15)<0){return(0)}
    else{return(1-(trans-0.15)/(0.75-0.15))
      }
      }

    Run the code above in your browser using DataLab