Usage
Lumped_VSA_model(dateSeries, P, Tmax, Tmin, Depth = NULL, SATper = NULL, AWCper = NULL,
percentImpervious = 0, no_wet_class = 10, Tp = 5, latitudeDegrees = 42.38, albedo = 0.23,
StartCond = "avg", PETin = NULL, AWC = Depth * AWCper, SAT = Depth * SATper, SW1 = NULL,
BF1 = 1, PETcap = 5, rec_coef = 0.1, Se_min = 78, C1 = 3.1, Ia_coef = 0.05,
PreviousOutput = NULL, runoff_breakdown = RunoffBreakdown(Tp, HrPrcDelay = (Tp/2 - 4)))
Arguments
dateSeries
Daily date series in the format "2013-05-21"
Depth
Average watershed soil depth (mm)
Not needed if SAT and AWC depth entered directly
SATper
Porosity of the soil (volumetric fraction, 0-1)
Not needed if SAT (porosity depth) entered directly
AWCper
Available water capacity, Field capacity - wilting point (volumetric fraction, 0-1)
Not needed if AWC entered directly
percentImpervious
Percent of the watershed that is impervious (percentage, 0-100
no_wet_class
Number of wetness classes to distribute runoff over. Default is 10.
Tp
Time to peak of hydrograph (hours)
latitudeDegrees
latitude (degrees)
albedo
Average surface albedo, defaults to average 0.23
StartCond
Watershed conditions before first day of run (options are "wet", "dry", "avg")
PETin
# User has the option to enter PET values (mm/day), otherwise this will be estimated from Priestley-Taylor equation, estimating radiation from temperature
SW1
Soil water on the first day (depth, mm)
BF1
Baseflow on the first day (mm/day)
PETcap
Cutoff for maximal PET allowed per day (mm)
rec_coef
Baseflow recession coefficient
Se_min
Minimal daily CN S value. (mm)
C1
Coefficient relating daily Curve Number S to soil water
Ia_coef
Initial abstraction coefficient for CN-equation. (range ~ 0.05 - 0.2)
PreviousOutput
If the model is run repeatedly, previous output can be provided so that the model only needs to calculate from that point forward.
runoff_breakdown
The proportion of runoff that reaches the outlet on a given day after the storm event. Can be calculated from Tp