Usage
PET_fromTemp(Jday, Tmax_C, Tmin_C, lat_radians, AvgT = (Tmax_C + Tmin_C)/2, albedo = 0.18, TerrestEmiss = 0.97, aspect = 0, slope = 0, forest = 0, PTconstant=1.26)
Arguments
Tmax_C
Maximum daily temperature (degrees C)
Tmin_C
Minimum daily temperature (degrees C)
lat_radians
latitude (radians = decimal degrees*pi/180)
AvgT
Average daily temperature (degrees C) (if not known, will be taken as the averages of the daily extremes)
albedo
(-) average surface albedo. Can be expressed as a single value, or as a vector with the same length as Jday, Tmax_C and Tmin_C
TerrestEmiss
(-) Surface Emissivity - defaults to 0.97
aspect
(radians) Surface aspect
slope
(radians) average slope
forest
(-) Forest or shade cover (0-1). This modifies the amount of solar radiation reaching the location of interest. It should always set to zero for landscape-wide processes regardless of the amount of forest present. Only change this if calculating PET un
PTconstant
(-) Priestley-Taylor Constant, often 1.26