Learn R Programming

EcoHydRology (version 0.4.3)

PET_fromTemp: Potential Evapotranspiration

Description

Calculates potential Evapotranspiration (in meters) based on the Priestley-Taylor equation (1972). We use an estimation of net radiation based on temperature data.

Usage

PET_fromTemp(Jday, Tmax_C, Tmin_C, lat_radians, AvgT = (Tmax_C + Tmin_C)/2, albedo = 0.18, TerrestEmiss = 0.97, aspect = 0, slope = 0, forest = 0)

Arguments

Jday
Day of the year
Tmax_C
Maximum daily temperature (degrees C)
Tmin_C
Minimum daily temperature (degrees C)
lat_radians
latitude (radians = decimal degrees*pi/180)
AvgT
Average daily temperature (degrees C) (if not known, will be taken as the averages of the daily extremes)
albedo
(-) average surface albedo. Can be expressed as a single value, or as a vector with the same length as Jday, Tmax_C and Tmin_C
TerrestEmiss
(-) Surface Emissivity - defaults to 0.97
aspect
(-) Surface aspect
slope
(-) average slope
forest
(-) Forest cover. Always set to zero for landscape-wide processes. Only change if calculating PET under a canopy

Value

  • PET (potential evapotranspiration) in m

References

Priestley and Taylor (1972). On the assessment of surface heat flux and evaporation using large-scale parameters. Mon. Weath. Rev. 100: 81-92

Examples

Run this code
data(OwascoInlet)
head(OwascoInlet)
attach(OwascoInlet)
PETapprox<-PET_fromTemp(Jday=(1+as.POSIXlt(date)$yday), Tmax_C=Tmax_C, Tmin_C=Tmin_C, lat_radians=42.45*pi/180)
plot(PETapprox*1000~date, type="l")
detach(OwascoInlet)

Run the code above in your browser using DataLab