Learn R Programming

EcoHydRology (version 0.3.7)

build_swat_basic: This function builds a basic SWAT initialization.

Description

This function builds a basic SWAT initialization. It will ask for a directory to put the data into, and then change into that directory. You can then run the example using runSWAT() function.

Usage

build_swat_basic()

Arguments

Value

    Examples

    Run this code
    ##---- Should be DIRECTLY executable !! ----
    ##-- ==>  Define data, use random,
    ##--	or do  help(data=index)  for the standard data sets.
    
    ## The function is currently defined as
    function(){
    tmpdir=readline("Please enter a temp directory where you want to build your run...
    ")
    dir.create(tmpdir)
    setwd(tmpdir)
    for (file in names(swat_general)){print(file); cat(unlist(swat_general[file]),file=file,sep="")}
      }

    Run the code above in your browser using DataLab