Learn R Programming

EcoHydRology (version 0.4.3)

get_usgs_gage: A function to grab daily stream flow measurements from the USGS waterdata.usgs.gov server.

Description

A function to grab daily stream flow measurements from the USGS waterdata.usgs.gov server.

Usage

get_usgs_gage(gage)

Arguments

gage
gage Gage is a TEXT/String rather than numeric or the query will fail on gages with leading 0s

Value

  • areaIs the area above the gage
  • declatDecimal Lat
  • declonDecimal Lon
  • flowdataDataframe with the historical flow data

Examples

Run this code
flowgage_id="04216500"
flowgage=get_usgs_gage(flowgage_id)

## The function is currently defined as

Run the code above in your browser using DataLab